@@ -1,15 +1,17 @@
 import threading
 from .LogLevel import LogLevel
-from iupdatable.system.io.Directory import Directory
 import logging as sys_logging
 import logging.handlers
-import datetime
 import sys
 from colorlog import ColoredFormatter
+from concurrent_log_handler import ConcurrentRotatingFileHandler   # 解决多线程读写同一日志文件造成进程无法访问的问题
 
 
 class Logger(object):
+    _debug_logger = None
+    _logger = None
     _instance_lock = threading.Lock()
+    _is_init = False
 
     def __init__(self):
         pass
@@ -124,10 +126,11 @@ class Logger(object):
         # 设置日志输出到文件
         if is_output_file:
             # 输出到文件的 handler
-            logger_file_handler = sys_logging.handlers.TimedRotatingFileHandler(
-                log_file_full_path,
-                when='midnight', interval=1, backupCount=7,
-                atTime=datetime.time(0, 0, 0, 0))
+            # logger_file_handler = sys_logging.handlers.TimedRotatingFileHandler(
+            #     log_file_full_path,
+            #     when='midnight', interval=1, backupCount=7)
+            logger_file_handler = ConcurrentRotatingFileHandler(
+                log_file_full_path, backupCount=7)
             logger_file_handler.suffix = "%Y-%m-%d.log"
             logger_file_handler.setFormatter(logger_formatter)
             logger.addHandler(logger_file_handler)
